@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.34';
+our $VERSION = '0.2.35';
 
 1;
 
@@ -121,7 +121,7 @@ sub populate_config {
         }
     }
 
-    my $default_config = {};
+    my $default_config;
 
     if ( -f 'suite.ini' ){
       my $path = 'suite.ini';
@@ -131,8 +131,20 @@ sub populate_config {
         -ConfigFile => $path 
       )->getall or confess "file $path is not valid config file";
       $default_config = {%c}; 
+    }elsif ( -f 'suite.yaml'){
+      my $path = 'suite.yaml';
+      ($default_config) = LoadFile($path);
+    }elsif ( -f 'suite.json'){
+      my $path = 'suite.json';
+      open DATA, $path or confess "can't open file $path to read: $!";
+      my $json_str = join "", <DATA>;
+      close DATA;
+      $default_config = from_json($json_str);
+    }else{
+      $default_config = { };
     }
 
+
     my @runtime_params;
 
     if (my $args_file = get_prop('args_file') ){
@@ -1387,6 +1399,58 @@ Outthentic provides some helpers and variables:
 (*) you need to C<from outthentic import *> in Python to import os() function.
 
 
+=head3 Recognized OS list
+
+=over
+
+=item -
+
+centos5
+
+
+=item -
+
+centos6
+
+
+=item -
+
+centos7
+
+
+=item -
+
+ubuntu
+
+
+=item -
+
+debian
+
+
+=item -
+
+minoca
+
+
+=item -
+
+archlinux
+
+
+=item -
+
+fedora
+
+
+=item -
+
+amazon
+
+
+=back
+
+
 =head2 Meta stories
 
 Meta stories are special type of outthentic stories.
